@@ -35,16 +35,18 @@ def _d1_sdist2rpm():
     # grab the name and create a normalized one
     popen = subprocess.Popen('%s setup.py --name' % sys.executable,
                                 stdout=subprocess.PIPE, shell=True)
-    name = popen.stdout.read().split('\n')
+    name = [line for line in popen.stdout.read().split('\n') if line != '']
     name = name[-1].strip().lower()
+    major, minor = sys.version_info[0], sys.version_info[1]
 
-    if not name.startswith('python-'):
-        name = 'python-%s' % name
+    # getting the python version
+    if not name.startswith('python'):
+        name = 'python%d%d-%s' % (major, minor, name)
 
     # run the bdist_rpm2 command
-    cmd = 'bdist_rpm2 --command-packages=pypi2rpm.command --fix-python'
+    cmd = '--command-packages=pypi2rpm.command bdist_rpm2 --fix-python'
     res = subprocess.call('%s setup.py %s --name=%s' % \
-            (cmd, sys.executable, name), shell=True)
+            (sys.executable, cmd, name), shell=True)
     if res != 0:
         print('Could not create RPM')
         sys.exit(0)
